#*******************************************************************************
#
#   Licensed Materials - Property of IBM
#  
#   5724-T01 5724-S98
#  
#   (C) Copyright IBM Corp. 2003, 2009. All Rights Reserved.
#  
#   US Government Users Restricted Rights - Use, duplication or
#   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*****************************************************************************#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#

package EngineConfig;


@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

#use diagnostics;
use strict;
use Exporter ();
use Data::Dumper;

use Date::Calc qw(Decode_Month Add_Delta_YMDHMS);

#-------------------------------------------------------------------------------


#-------------------------------------------------------------------------------
# Modify/Add rules here
#-------------------------------------------------------------------------------
my @rules = 
    (
     {
        'RULE_TYPE' => 'GENERIC_CSV_GATEWAY',
        'RULE_DESC' => 'Motorola GGSN v50',
        'INPUT_FILE_DESCRIPTION' => [ '^PassiveCollector.*$' ],
        'INPUT_DIR_DEPTH' => 0,
	    
        'ORDER_OF_FILES' => 'OLDEST_FIRST',

	 	'FIELD_SEPARATOR'            => ',',
	 	
		# valnt00043794 move the systemName and SystemAddressName to data fields
	 	'HEADER_FIELDS'      => [ 3 ],
	 	'DATA_FIELDS'                => [ 0,1,2,4..100 ],  ## remove field 3 later
	 	'INVALID_VALUE_MATCH'        => [],
	 	'WHITESPACE_MODIFIER'        => '_',   ## whitespaces between counter names are converted to underscores.
	 	'FIELDS_TO_KEY_PIF_FILENAME' => [],
	 	'DEFAULT_NULL_VALUE'         => '',
	 	'UPPERCASE_COUNTERS'         => 0,
	 	'FILENAME_HEADER_FIELDS'      => {
			FILENAME	=> '(.*)',
		        BLOCKNAME	=> 'PassiveCollector-\w+\.[A-Za-z\.\-]*_([A-Za-z]*)_[0-9]{2}_[0-9]{2}_[0-9]{4}_[0-9]{2}_[0-9]{2}_[0-9]{2}\.csv',
	 	},

	 	HEADER_DATA_RECORD_PROCESSING => sub 
	 	{
			 my ($blk_name_ref, $h_ref, $d_ref) = @_;
			 my $cname_new;
			 my $cname_ori;
			 
			 
		         # Set block name
		 	 $$blk_name_ref = $h_ref->{BLOCKNAME};
	         $d_ref->{startTime} = timeRounding($d_ref->{startTime});
	         $d_ref->{endTime} = timeRounding($d_ref->{endTime});
	         
	         
	         if($d_ref->{startTime} == $d_ref->{endTime}){
		         
		         $d_ref->{endTime}= $d_ref->{endTime} + 900;
	         }
	          
	         ## TESTING PURPOSES:
	         foreach my $cname_ori (keys %{$d_ref}){
			
				 $d_ref->{$cname_new} = $d_ref->{$cname_ori};  
		 }	             

			 
	         sub timeRounding(){
	        	my $time = shift;    
				my $min = $time%3600;
				my $hr = ($time - $min)/3600; 
				
				my $freq = 900;
				my $nearestTime = $time % $freq;
			         
				if($nearestTime !=0 ){   ## check if it is already in the "normalized" time standards 
			            $time = $time - $nearestTime;
			 	}
			         
			 	### DEBUG PURPOSES ONLY
				$min = $time %3600; 
				$hr = ($time - $min)/3600; 
				
			 	return	$time;
			} 	 
			return 0;
		}
	},
);  


sub engine_config {
    return \@rules;
}

1;
